import { Component, ContentChild, Directive, HostBinding, HostListener, Input, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

var InputRefDirective = (function () {
    function InputRefDirective() {
        this.focus = false;
    }
    /**
     * @return {?}
     */
    InputRefDirective.prototype.onFocus = function () {
        this.focus = true;
    };
    /**
     * @return {?}
     */
    InputRefDirective.prototype.onBlur = function () {
        this.focus = false;
    };
    return InputRefDirective;
}());
InputRefDirective.decorators = [
    { type: Directive, args: [{
                selector: '[agInput]'
            },] },
];
/**
 * @nocollapse
 */
InputRefDirective.ctorParameters = function () { return []; };
InputRefDirective.propDecorators = {
    'onFocus': [{ type: HostListener, args: ['focus',] },],
    'onBlur': [{ type: HostListener, args: ['blur',] },],
};

var commonCss = "\n.icon{\n  width:25px;\n  text-align: center;\n  padding-left: 5px;\n  padding-right: 2px;\n  border:none;\n}\n\n:host{\n  border-width: 1px;\n  border-style: solid;\n  padding-bottom: 1px;\n  padding-top: 1px;\n  display: inline-block;\n}\n\n\n:host(.input-focus){\n  outline: none;\n}\n:host /deep/ input{\n  border: none;\n  outline: none;\n  height: 100%;\n  box-sizing: border-box;\n}\n";

var defaultThemeCss = "\n:host{\n  background: white;\n  border-color: lightgray;\n}\n\n:host(.input-focus){\n  border-color: #4D90FE;\n  -webkit-box-shadow: 0px 0px 5px #4D90FE;\n  box-shadow: 0px 0px 5px #4D90FE;\n}\n";

var AgFaInputComponent = (function () {
    function AgFaInputComponent() {
    }
    /**
     * @return {?}
     */
    AgFaInputComponent.prototype.ngAfterContentInit = function () {
        if (!this.input) {
            console.error('ag-fa-input component need input inside its content');
        }
    };
    Object.defineProperty(AgFaInputComponent.prototype, "isInputFocus", {
        /**
         * @return {?}
         */
        get: function () {
            return this.input ? this.input.focus : false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AgFaInputComponent.prototype, "classes", {
        /**
         * @return {?}
         */
        get: function () {
            var /** @type {?} */ cssClasses = {};
            if (this.icon) {
                cssClasses['fa-' + this.icon] = true;
            }
            return cssClasses;
        },
        enumerable: true,
        configurable: true
    });
    return AgFaInputComponent;
}());
AgFaInputComponent.decorators = [
    { type: Component, args: [{
                selector: 'ag-fa-input',
                template: "\n              <i class=\"icon fa\" [ngClass]=\"classes\"></i>\n              <ng-content></ng-content>\n            ",
                styles: [commonCss, defaultThemeCss]
            },] },
];
/**
 * @nocollapse
 */
AgFaInputComponent.ctorParameters = function () { return []; };
AgFaInputComponent.propDecorators = {
    'icon': [{ type: Input },],
    'input': [{ type: ContentChild, args: [InputRefDirective,] },],
    'isInputFocus': [{ type: HostBinding, args: ['class.input-focus',] },],
};

var AgInputModule = (function () {
    function AgInputModule() {
    }
    return AgInputModule;
}());
AgInputModule.decorators = [
    { type: NgModule, args: [{
                declarations: [AgFaInputComponent, InputRefDirective],
                imports: [
                    CommonModule
                ],
                exports: [AgFaInputComponent, InputRefDirective]
            },] },
];
/**
 * @nocollapse
 */
AgInputModule.ctorParameters = function () { return []; };

/**
 * Generated bundle index. Do not edit.
 */

export { AgInputModule, AgFaInputComponent as ɵa, commonCss as ɵb, defaultThemeCss as ɵc, InputRefDirective as ɵd };
//# sourceMappingURL=ag-input.es5.js.map
