import { Component, ContentChild, Directive, HostBinding, HostListener, Input, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

class InputRefDirective {
    constructor() {
        this.focus = false;
    }
    /**
     * @return {?}
     */
    onFocus() {
        this.focus = true;
    }
    /**
     * @return {?}
     */
    onBlur() {
        this.focus = false;
    }
}
InputRefDirective.decorators = [
    { type: Directive, args: [{
                selector: '[agInput]'
            },] },
];
/**
 * @nocollapse
 */
InputRefDirective.ctorParameters = () => [];
InputRefDirective.propDecorators = {
    'onFocus': [{ type: HostListener, args: ['focus',] },],
    'onBlur': [{ type: HostListener, args: ['blur',] },],
};

const commonCss = `
.icon{
  width:25px;
  text-align: center;
  padding-left: 5px;
  padding-right: 2px;
  border:none;
}

:host{
  border-width: 1px;
  border-style: solid;
  padding-bottom: 1px;
  padding-top: 1px;
  display: inline-block;
}


:host(.input-focus){
  outline: none;
}
:host /deep/ input{
  border: none;
  outline: none;
  height: 100%;
  box-sizing: border-box;
}
`;

const defaultThemeCss = `
:host{
  background: white;
  border-color: lightgray;
}

:host(.input-focus){
  border-color: #4D90FE;
  -webkit-box-shadow: 0px 0px 5px #4D90FE;
  box-shadow: 0px 0px 5px #4D90FE;
}
`;

class AgFaInputComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        if (!this.input) {
            console.error('ag-fa-input component need input inside its content');
        }
    }
    /**
     * @return {?}
     */
    get isInputFocus() {
        return this.input ? this.input.focus : false;
    }
    /**
     * @return {?}
     */
    get classes() {
        const /** @type {?} */ cssClasses = {};
        if (this.icon) {
            cssClasses['fa-' + this.icon] = true;
        }
        return cssClasses;
    }
}
AgFaInputComponent.decorators = [
    { type: Component, args: [{
                selector: 'ag-fa-input',
                template: `
              <i class="icon fa" [ngClass]="classes"></i>
              <ng-content></ng-content>
            `,
                styles: [commonCss, defaultThemeCss]
            },] },
];
/**
 * @nocollapse
 */
AgFaInputComponent.ctorParameters = () => [];
AgFaInputComponent.propDecorators = {
    'icon': [{ type: Input },],
    'input': [{ type: ContentChild, args: [InputRefDirective,] },],
    'isInputFocus': [{ type: HostBinding, args: ['class.input-focus',] },],
};

class AgInputModule {
}
AgInputModule.decorators = [
    { type: NgModule, args: [{
                declarations: [AgFaInputComponent, InputRefDirective],
                imports: [
                    CommonModule
                ],
                exports: [AgFaInputComponent, InputRefDirective]
            },] },
];
/**
 * @nocollapse
 */
AgInputModule.ctorParameters = () => [];

/**
 * Generated bundle index. Do not edit.
 */

export { AgInputModule, AgFaInputComponent as ɵa, commonCss as ɵb, defaultThemeCss as ɵc, InputRefDirective as ɵd };
//# sourceMappingURL=ag-input.js.map
